==> serendipity_1.0.4.orig.tar.gz: serendipity/plugins/serendipity_event_creativecommons/UTF-8/lang_zh.inc.php <==
<?php # $Id: $

##########################################################################
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity    #
# Developer Team) All rights reserved.  See LICENSE file for licensing   #
# details								                                                 #
#                                                                        #
# (c) 2003 Jannis Hermanns <J@hacked.it>                                 #
# http://www.jannis.to/programming/serendipity.html                      #
#                                                                        #
# Translated by                                                          #
# (c) 2006 Demin Yin <damon@deminy.net>                                  #
#               http://www.deminy.net                                    #
##########################################################################

@define('PLUGIN_CREATIVECOMMONS_NAME',        '创作共用协议');
@define('PLUGIN_CREATIVECOMMONS_DESC',        '请选择适合您的创作共用协议');
@define('PLUGIN_CREATIVECOMMONS_TXT',         '显示文本?');
@define('PLUGIN_CREATIVECOMMONS_TXT_DESC',    '为了正确传达协议信息，请对所选协议提供一份简要说明。');
@define('PLUGIN_CREATIVECOMMONS_CAP',         '该原创内容遵循“<a href="#license_uri#">创作共用协议</a>”');
@define('PLUGIN_CREATIVECOMMONS_CAP_PD',      '该原创内容使用<a href="#license_url#}">公共领域</a>条款。');
// @define('PLUGIN_CREATIVECOMMONS_BY',          '需要分发？');
// @define('PLUGIN_CREATIVECOMMONS_BY_DESC',     '作者允许他人复制、分发、演示、使用该作品。同时，使用者需向原作者支付报酬。');
@define('PLUGIN_CREATIVECOMMONS_NC',          '允许将您的作品用于商业用途？');
@define('PLUGIN_CREATIVECOMMONS_NC_DESC',     '作者允许他人复制、分发、演示、使用该作品。同时，使用者不得将该作品用于商业用途，除非得到作者授权。');
@define('PLUGIN_CREATIVECOMMONS_ND',          '允许修改您的作品?');
@define('PLUGIN_CREATIVECOMMONS_ND_DESC',     '作者只允许他人复制、分发、演示、使用未被修改的该作品。');
@define('PLUGIN_CREATIVECOMMONS_SA_DESC',     '允许，如果用途相同的话');

?>

==> serendipity_1.1.4.orig.tar.gz: serendipity/plugins/serendipity_event_creativecommons/UTF-8/lang_zh.inc.php <==
<?php # $Id: lang_zh.inc.php 1381 2006-08-15 10:14:56Z elf2000 $

##########################################################################
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity    #
# Developer Team) All rights reserved.  See LICENSE file for licensing   #
# details								                                 #
#                                                                        #
# (c) 2003 Jannis Hermanns <J@hacked.it>                                 #
# http://www.jannis.to/programming/serendipity.html                      #
#                                                                        #
# Translated by                                                          #
# (c) 2006 Aphonex Li <aphonex.li@gmail.com>                             #
#               http://www.exten.cn                                      #
##########################################################################

@define('PLUGIN_CREATIVECOMMONS_NAME',        '创作共用协议');
@define('PLUGIN_CREATIVECOMMONS_DESC',        '请选择适合您的创作共用协议');
@define('PLUGIN_CREATIVECOMMONS_TXT',         '显示文本?');
@define('PLUGIN_CREATIVECOMMONS_TXT_DESC',    '为了正确传达协议信息，请对所选协议提供一份简要说明。');
@define('PLUGIN_CREATIVECOMMONS_CAP',         '该原创内容遵循“<a href="#license_uri#">创作共用协议</a>”');
@define('PLUGIN_CREATIVECOMMONS_CAP_PD',      '该原创内容使用<a href="#license_url#}">公共领域</a>条款。');
@define('PLUGIN_CREATIVECOMMONS_BY',          '需要分发？');
@define('PLUGIN_CREATIVECOMMONS_BY_DESC',     '作者允许他人复制、分发、演示、使用该作品。同时，使用者需向原作者支付报酬。');
@define('PLUGIN_CREATIVECOMMONS_NC',          '允许将您的作品用于商业用途？');
@define('PLUGIN_CREATIVECOMMONS_NC_DESC',     '作者允许他人复制、分发、演示、使用该作品。同时，使用者不得将该作品用于商业用途，除非得到作者授权。');
@define('PLUGIN_CREATIVECOMMONS_ND',          '允许修改您的作品?');
@define('PLUGIN_CREATIVECOMMONS_ND_DESC',     '作者只允许他人复制、分发、演示、使用未被修改的该作品。');
@define('PLUGIN_CREATIVECOMMONS_SA_DESC',     '允许，如果用途相同的话');

?>
